# coding: utf-8

"""
    tosca-sure

    TOSCA Simple qUeRy sErvice (SURE).   # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: S.Koulouzis@uva.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301

short_desc = "This is a python client for the sure_tosca REST service"

try:
    with open("./README.md", "r") as rm:
        long_description = rm.read()
except FileNotFoundError:
    long_description = short_desc


NAME = "sure_tosca_client"
VERSION = "1.0.3"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
"certifi==2020.4.5.1",
"six==1.14.0",
"setuptools==46.1.3",
"urllib3==1.25.8",
"numpy==1.18.2"
]







setup(
    name=NAME,
    version=VERSION,
    description=short_desc,
    author_email="S.Koulouzis@uva.nl",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/qcdis-sdia/sdia-sure_tosca-client",
    keywords=["Swagger", "tosca-sure"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7'
)







