# coding: utf-8

"""
    tosca-sure

    TOSCA Simple qUeRy sErvice (SURE).   # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: S.Koulouzis@uva.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sure_tosca_client
from sure_tosca_client.models.tosca_template import ToscaTemplate  # noqa: E501
from sure_tosca_client.rest import ApiException


class TestToscaTemplate(unittest.TestCase):
    """ToscaTemplate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testToscaTemplate(self):
        """Test ToscaTemplate"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.tosca_template.ToscaTemplate()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
